# -----------------------------------------------------------------------------
sub oraBkupArc
# -----------------------------------------------------------------------------
{
  ($thishost) = @_;

  if ($up[$thishost] ne "Y")
  {
    &logit("(Down/Inhibited)",$thishost);
    return 1; 
  }

  if ($asmflag[$thishost])
  {
    &logit("(This check not applicable to +ASM instance)",$thishost);
    return 1;
  }

  $this_age = $mr_age_arc[$thishost];

  # Return if they don't want age checking for this instance
  if ($backup_age_arc[$thishost] eq "N")
  {
    &logit("ARC Backup Age Checking not requested for this instance",$thishost);
    return 0;
  }
  if ($arclog[$thishost] eq "" || $arclog[$thishost] eq "NoArcLog")
  {
    &logit("This instance is in NOARCHIVELOG mode - Not checking ARC backup age - arclog=$arclog[$thishost]",$thishost);
    return 0;
  }
  if ($standby[$thishost] eq "STANDBY")
  {
    &logit("This instance is a STANDBY - Not checking ARC backup age",$thishost);
    return 0;
  }
  if ($ops[$thishost] eq "YES" && $inst_num[$thishost] > 1)
  {
    &logit("This instance is RAC Thread >1 - Not checking ARC backup age",$thishost);
    return 0;
  }

  if ($backup_age_arc[$thishost] eq "")
  {
    &logit("ARC Backup Age Checking not specified - using Default $df_ba_arc=df_ba_arc",$thishost);
    $backup_age_arc[$thishost] = $df_ba_arc;
    $maxsev = "C";
  }
  else
  {
    $maxsev = "C";
  }

  #
  # bb 11Oct99 - Check to see if there is a backup age inhibit 
  # entry.
  #
  if ($use_repository eq "Y")
  {
    $rc = &baICheck($thishost);
    if ($rc > 0)
    {
      $backup_method_long[$thishost] = "bkInhibit";
      $bainhibit[$thishost] = 1;
      $bckhours[$thishost]   = "(I)";
      $msg = sprintf("Backup Age Checking Inhibited - Start: %s End: %s Created: %s User: %s Reason: %s",$bai_sts,$bai_ets,$bai_ts,$bai_user,$bai_reason);
      &logit($msg,$thishost);
      return 0;
    }
  }
  else
  {
    logit("Backup Aging Inhibit not possible because Use_Oracle != Y",$thishost);
  }

  #
  # Check age vs. threashold - backup NOT running
  #

  # Just in case we exceed, set these vars and make report
  $rounded1 = int($this_age / 10);
  $rounded1 = $rounded1 * 10;
  $rounded2 = $rounded1 + 9;

  $bckhours_c_arc[$thishost] = "black";

  $msg  = "RMAN Backup Details:\n";
  $msg .= "Hours since last ARC backup: $this_age\n";
  $msg .= "Threshold for this instance: $backup_age_arc[$thishost]\n";
  $msg .= "Backup Rerun Command for this instance: $backup_command_arc[$thishost]\n";
  $msg .= "Most recent *Any* backup age (hours): $mr_age[$thishost]\n";
  $msg .= "Most recent ARC backup age (hours): $mr_age_arc[$thishost]\n";
  $msg .= "Most recent LVL0 backup age (hours): $mr_age_lvl0[$thishost]\n";
  $msg .= "Most recent LVL1 backup age (hours): $mr_age_lvl1[$thishost]\n";

  system("rm $tmpfl6 > /dev/null 2>&1");
  open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
  print TMPFL6 $msg;
  close(TMPFL6);

  if ($this_age == -1)
  {
    $bckhours_c_arc[$thishost] = "hotpink";
    $bckmsg = "ARC Backup Never Run"; 
    &event("$maxsev",$thishost,"$bckmsg - threshold: $backup_age_arc[$thishost]","BkpAgeArcNever","DBA511",$tmpfl6);
  }

  ##print "this_age=$this_age t=$backup_age_arc[$thishost] \n";

  #---- Check against threshold
  if ($this_age > $backup_age_arc[$thishost])
  {
    $bckmsg = "$rounded1-$rounded2 Hours since last good ora_backup ARC backup";

    if ($backup_running_arc[$thishost] eq "Y")
    {
      $running_str = "(ARC Backup IS Running Now)";
      $bckhours_c_arc[$thishost] = "yellow";
      &event("U",$thishost,"$bckmsg - threshold: $backup_age_arc[$thishost] $running_str","BkpAgeArc","DBA512",$tmpfl6);
    }
    else
    {
      #
      # 3.23D 08Jul00 BB
      #   we did not issue the restart on the last iteration
      #   (in which case it should be running now), then issue
      #   the restart command.
      #
      ##if ($company eq "thecompany")
      ##{
      ##  chop($datechk = `date +%C%y/%m/%d-%H:%M:%S`);
      ##  if ($datechk ge "2001/05/19-12:00:00" &&  $datechk le "2001/05/21-10:00:00")
      ##  {
      ##    $backup_command[$thishost] = "";
      ##    logit("Backup_Command: Forced to NULL for host: $hostname[$thishost]:$title1[$thishost] ");
      ##  }
      ##}

      if ($backup_command_arc[$thishost] ne "" && $backup_rerun_iter_arc[$thishost] != ($iter_count - 1) )
      {
        # Issue rerun
        $cmd = "$probe[$thishost] bkrun \"$backup_command[$thishost]\"";
        ##print "backup rerun cmd=$cmd \n";
	remsh($cmd,$tmpfl3,$thishost);
        ##print "tmpf3: \n";
	##system("cat $tmpfl3");
        $backup_rerun_iter_arc[$thishost] = $iter_count;

        # warning event
	$running_str = "(ARC Backup Was Rerun)";
	$bckhours_c_arc[$thishost] = "yellow";

        &event("W",$thishost,"$bckmsg - threshold: $backup_age_arc[$thishost] $running_str","BkpAgeArc","DBA511",$tmpfl6);
      }
      else
      {
	$running_str = "(ARC Backup IS NOT Running Now)";
	$bckhours_c_arc[$thishost] = "hotpink";

        &event("$maxsev",$thishost,"$bckmsg - threshold: $backup_age_arc[$thishost] $running_str","BkpAgeArc","DBA511",$tmpfl6);
      }
    }
  }
  else    # Age not exceeded
  {
    $msg = sprintf("OK - Age=%s Threshold=%s",$this_age,$backup_age_arc[$thishost]);
    &logit($msg,$thishost);
  }

  #---- Verify that a backup schedule exists
  &debug($thishost, "bkup_sched_arc[$thishost]=$bkup_sched_arc[$thishost]");
  if (
      $bkup_sched_arc[$thishost] ne "" &&
      $bkup_sched_arc[$thishost] != 1
     )
  {
    #---- No schedule exists for this DB
    #---- See if a backup age risk acceptance exists and is current for this instance
    eval 'require "risk_acceptance.pl";';

    #foreach (sort keys %backupNo) { print "DEBUG backupNo{$_}=$backupNo{$_}\n"; }
    $key = $titleraw_slash[$thishost];
    chop($today = `date +%Y/%m/%d`);
    &debug($thishost, "backupNo{$key}=$backupNo{$key} today=$today");

    if ($backupNo{$key} && $today lt $backupNo{$key})
    {
      &logit("Backup Schedule not found, but valid RA exists - Backup Type: ARC*",$thishost);
    }
    else
    {
      #---- If in NOARCHIVELOG mode, then NO EVENT
      if ($arclog[$thishost] eq "NoArcLog")
      {
        &logit("This DB is in NOARCHIVELOG mode, so an ARC backup schedule is not applicable - arclog=$arclog[$thishost]",$thishost);
      }
      #---- If this is a STANDBY, no event
      elsif ($standby[$thishost] eq "STANDBY")
      {
        &logit("This DB is a STANDBY, so an ARC backup schedule is not applicable - standby=$standby[$thishost]",$thishost);
      }
      else
      {
        &event("C",$thishost,"Normal Backup Schedule Not Found - DB In $arclog[$thishost] Mode - Backup Type: ARC","BkupSchedARC","DBA380");
      }
    }
  }

}
# -----------------------------------------------------------------------------
1;
